@@ -6,7 +6,6 @@ import (
 	"github.com/jesseduffield/gocui"
 	"github.com/jesseduffield/lazygit/pkg/gui/status"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
-	"github.com/jesseduffield/lazygit/pkg/utils"
 )
 
 type AppStatusHelper struct {
@@ -60,26 +59,20 @@ func (self appStatusHelperTask) Continue() {
 
 // withWaitingStatus wraps a function and shows a waiting status while the function is still executing
 func (self *AppStatusHelper) WithWaitingStatus(message string, f func(gocui.Task) error) {
-	self.c.OnWorker(func(task gocui.Task) {
-		self.statusMgr().WithWaitingStatus(message, self.renderAppStatus, func(waitingStatusHandle *status.WaitingStatusHandle) {
-			if err := f(appStatusHelperTask{task, waitingStatusHandle}); err != nil {
-				self.c.OnUIThread(func() error {
-					return self.c.Error(err)
-				})
-			}
+	self.c.OnWorker(func(task gocui.Task) error {
+		return self.statusMgr().WithWaitingStatus(message, self.renderAppStatus, func(waitingStatusHandle *status.WaitingStatusHandle) error {
+			return f(appStatusHelperTask{task, waitingStatusHandle})
 		})
 	})
 }
 
-func (self *AppStatusHelper) WithWaitingStatusSync(message string, f func() error) {
-	self.statusMgr().WithWaitingStatus(message, func() {}, func(*status.WaitingStatusHandle) {
+func (self *AppStatusHelper) WithWaitingStatusSync(message string, f func() error) error {
+	return self.statusMgr().WithWaitingStatus(message, func() {}, func(*status.WaitingStatusHandle) error {
 		stop := make(chan struct{})
 		defer func() { close(stop) }()
 		self.renderAppStatusSync(stop)
 
-		if err := f(); err != nil {
-			_ = self.c.Error(err)
-		}
+		return f()
 	})
 }
 
@@ -88,16 +81,16 @@ func (self *AppStatusHelper) HasStatus() bool {
 }
 
 func (self *AppStatusHelper) GetStatusString() string {
-	appStatus, _ := self.statusMgr().GetStatusString()
+	appStatus, _ := self.statusMgr().GetStatusString(self.c.UserConfig)
 	return appStatus
 }
 
 func (self *AppStatusHelper) renderAppStatus() {
-	self.c.OnWorker(func(_ gocui.Task) {
-		ticker := time.NewTicker(time.Millisecond * utils.LoaderAnimationInterval)
+	self.c.OnWorker(func(_ gocui.Task) error {
+		ticker := time.NewTicker(time.Millisecond * time.Duration(self.c.UserConfig.Gui.Spinner.Rate))
 		defer ticker.Stop()
 		for range ticker.C {
-			appStatus, color := self.statusMgr().GetStatusString()
+			appStatus, color := self.statusMgr().GetStatusString(self.c.UserConfig)
 			self.c.Views().AppStatus.FgColor = color
 			self.c.OnUIThread(func() error {
 				self.c.SetViewContent(self.c.Views().AppStatus, appStatus)
@@ -105,9 +98,10 @@ func (self *AppStatusHelper) renderAppStatus() {
 			})
 
 			if appStatus == "" {
-				return
+				break
 			}
 		}
+		return nil
 	})
 }
 
@@ -130,7 +124,7 @@ func (self *AppStatusHelper) renderAppStatusSync(stop chan struct{}) {
 		for {
 			select {
 			case <-ticker.C:
-				appStatus, color := self.statusMgr().GetStatusString()
+				appStatus, color := self.statusMgr().GetStatusString(self.c.UserConfig)
 				self.c.Views().AppStatus.FgColor = color
 				self.c.SetViewContent(self.c.Views().AppStatus, appStatus)
 				// Redraw all views of the bottom line:
