@@ -9,10 +9,12 @@ import (
 
 	"github.com/jesseduffield/gocui"
 	"github.com/jesseduffield/lazygit/pkg/commands/git_commands"
+	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/commands/types/enums"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/jesseduffield/lazygit/pkg/utils"
 	"github.com/samber/lo"
+	"github.com/stefanhaller/git-todo-parser/todo"
 )
 
 type MergeAndRebaseHelper struct {
@@ -110,7 +112,12 @@ func (self *MergeAndRebaseHelper) genericMergeCommand(command string) error {
 	// we should end up with a command like 'git merge --continue'
 
 	// it's impossible for a rebase to require a commit so we'll use a subprocess only if it's a merge
-	if status == enums.REBASE_MODE_MERGING && command != REBASE_OPTION_ABORT && self.c.UserConfig.Git.Merging.ManualCommit {
+	needsSubprocess := (status == enums.REBASE_MODE_MERGING && command != REBASE_OPTION_ABORT && self.c.UserConfig.Git.Merging.ManualCommit) ||
+		// but we'll also use a subprocess if we have exec todos; those are likely to be lengthy build
+		// tasks whose output the user will want to see in the terminal
+		(status == enums.REBASE_MODE_REBASING && command != REBASE_OPTION_ABORT && self.hasExecTodos())
+
+	if needsSubprocess {
 		// TODO: see if we should be calling more of the code from self.Git.Rebase.GenericMergeOrRebaseAction
 		return self.c.RunSubprocessAndRefresh(
 			self.c.Git().Rebase.GenericMergeOrRebaseActionCmdObj(commandType, command),
@@ -123,6 +130,18 @@ func (self *MergeAndRebaseHelper) genericMergeCommand(command string) error {
 	return nil
 }
 
+func (self *MergeAndRebaseHelper) hasExecTodos() bool {
+	for _, commit := range self.c.Model().Commits {
+		if commit.Status != models.StatusRebasing {
+			break
+		}
+		if commit.Action == todo.Exec {
+			return true
+		}
+	}
+	return false
+}
+
 var conflictStrings = []string{
 	"Failed to merge in the changes",
 	"When you have resolved this problem",
@@ -234,11 +253,29 @@ func (self *MergeAndRebaseHelper) PromptToContinueRebase() error {
 }
 
 func (self *MergeAndRebaseHelper) RebaseOntoRef(ref string) error {
-	checkedOutBranch := self.refsHelper.GetCheckedOutRef().Name
+	checkedOutBranch := self.refsHelper.GetCheckedOutRef()
+	checkedOutBranchName := self.refsHelper.GetCheckedOutRef().Name
+	var disabledReason, baseBranchDisabledReason *types.DisabledReason
+	if checkedOutBranchName == ref {
+		disabledReason = &types.DisabledReason{Text: self.c.Tr.CantRebaseOntoSelf}
+	}
+
+	baseBranch, err := self.c.Git().Loaders.BranchLoader.GetBaseBranch(checkedOutBranch, self.refsHelper.c.Model().MainBranches)
+	if err != nil {
+		return err
+	}
+	if baseBranch == "" {
+		baseBranch = self.c.Tr.CouldNotDetermineBaseBranch
+		baseBranchDisabledReason = &types.DisabledReason{Text: self.c.Tr.CouldNotDetermineBaseBranch}
+	}
+
 	menuItems := []*types.MenuItem{
 		{
-			Label: self.c.Tr.SimpleRebase,
-			Key:   's',
+			Label: utils.ResolvePlaceholderString(self.c.Tr.SimpleRebase,
+				map[string]string{"ref": ref},
+			),
+			Key:            's',
+			DisabledReason: disabledReason,
 			OnPress: func() error {
 				self.c.LogAction(self.c.Tr.Actions.RebaseBranch)
 				return self.c.WithWaitingStatus(self.c.Tr.RebasingStatus, func(task gocui.Task) error {
@@ -258,9 +295,12 @@ func (self *MergeAndRebaseHelper) RebaseOntoRef(ref string) error {
 			},
 		},
 		{
-			Label:   self.c.Tr.InteractiveRebase,
-			Key:     'i',
-			Tooltip: self.c.Tr.InteractiveRebaseTooltip,
+			Label: utils.ResolvePlaceholderString(self.c.Tr.InteractiveRebase,
+				map[string]string{"ref": ref},
+			),
+			Key:            'i',
+			DisabledReason: disabledReason,
+			Tooltip:        self.c.Tr.InteractiveRebaseTooltip,
 			OnPress: func() error {
 				self.c.LogAction(self.c.Tr.Actions.RebaseBranch)
 				baseCommit := self.c.Modes().MarkedBaseCommit.GetHash()
@@ -279,6 +319,31 @@ func (self *MergeAndRebaseHelper) RebaseOntoRef(ref string) error {
 				return self.c.PushContext(self.c.Contexts().LocalCommits)
 			},
 		},
+		{
+			Label: utils.ResolvePlaceholderString(self.c.Tr.RebaseOntoBaseBranch,
+				map[string]string{"baseBranch": ShortBranchName(baseBranch)},
+			),
+			Key:            'b',
+			DisabledReason: baseBranchDisabledReason,
+			Tooltip:        self.c.Tr.RebaseOntoBaseBranchTooltip,
+			OnPress: func() error {
+				self.c.LogAction(self.c.Tr.Actions.RebaseBranch)
+				return self.c.WithWaitingStatus(self.c.Tr.RebasingStatus, func(task gocui.Task) error {
+					baseCommit := self.c.Modes().MarkedBaseCommit.GetHash()
+					var err error
+					if baseCommit != "" {
+						err = self.c.Git().Rebase.RebaseBranchFromBaseCommit(baseBranch, baseCommit)
+					} else {
+						err = self.c.Git().Rebase.RebaseBranch(baseBranch)
+					}
+					err = self.CheckMergeOrRebase(err)
+					if err == nil {
+						return self.ResetMarkedBaseCommit()
+					}
+					return err
+				})
+			},
+		},
 	}
 
 	title := utils.ResolvePlaceholderString(
@@ -286,8 +351,7 @@ func (self *MergeAndRebaseHelper) RebaseOntoRef(ref string) error {
 			self.c.Tr.RebasingFromBaseCommitTitle,
 			self.c.Tr.RebasingTitle),
 		map[string]string{
-			"checkedOutBranch": checkedOutBranch,
-			"ref":              ref,
+			"checkedOutBranch": checkedOutBranchName,
 		},
 	)
 
@@ -305,25 +369,84 @@ func (self *MergeAndRebaseHelper) MergeRefIntoCheckedOutBranch(refName string) e
 	if checkedOutBranchName == refName {
 		return errors.New(self.c.Tr.CantMergeBranchIntoItself)
 	}
-	prompt := utils.ResolvePlaceholderString(
-		self.c.Tr.ConfirmMerge,
-		map[string]string{
-			"checkedOutBranch": checkedOutBranchName,
-			"selectedBranch":   refName,
-		},
-	)
 
-	return self.c.Confirm(types.ConfirmOpts{
-		Title:  self.c.Tr.MergeConfirmTitle,
-		Prompt: prompt,
-		HandleConfirm: func() error {
-			self.c.LogAction(self.c.Tr.Actions.Merge)
-			err := self.c.Git().Branch.Merge(refName, git_commands.MergeOpts{})
-			return self.CheckMergeOrRebase(err)
+	return self.c.Menu(types.CreateMenuOptions{
+		Title: self.c.Tr.Merge,
+		Items: []*types.MenuItem{
+			{
+				Label:   self.c.Tr.RegularMerge,
+				OnPress: self.RegularMerge(refName),
+				Key:     'm',
+				Tooltip: utils.ResolvePlaceholderString(
+					self.c.Tr.RegularMergeTooltip,
+					map[string]string{
+						"checkedOutBranch": checkedOutBranchName,
+						"selectedBranch":   refName,
+					},
+				),
+			},
+			{
+				Label:   self.c.Tr.SquashMergeUncommittedTitle,
+				OnPress: self.SquashMergeUncommitted(refName),
+				Key:     's',
+				Tooltip: utils.ResolvePlaceholderString(
+					self.c.Tr.SquashMergeUncommitted,
+					map[string]string{
+						"selectedBranch": refName,
+					},
+				),
+			},
+			{
+				Label:   self.c.Tr.SquashMergeCommittedTitle,
+				OnPress: self.SquashMergeCommitted(refName, checkedOutBranchName),
+				Key:     'S',
+				Tooltip: utils.ResolvePlaceholderString(
+					self.c.Tr.SquashMergeCommitted,
+					map[string]string{
+						"checkedOutBranch": checkedOutBranchName,
+						"selectedBranch":   refName,
+					},
+				),
+			},
 		},
 	})
 }
 
+func (self *MergeAndRebaseHelper) RegularMerge(refName string) func() error {
+	return func() error {
+		self.c.LogAction(self.c.Tr.Actions.Merge)
+		err := self.c.Git().Branch.Merge(refName, git_commands.MergeOpts{})
+		return self.CheckMergeOrRebase(err)
+	}
+}
+
+func (self *MergeAndRebaseHelper) SquashMergeUncommitted(refName string) func() error {
+	return func() error {
+		self.c.LogAction(self.c.Tr.Actions.SquashMerge)
+		err := self.c.Git().Branch.Merge(refName, git_commands.MergeOpts{Squash: true})
+		return self.CheckMergeOrRebase(err)
+	}
+}
+
+func (self *MergeAndRebaseHelper) SquashMergeCommitted(refName, checkedOutBranchName string) func() error {
+	return func() error {
+		self.c.LogAction(self.c.Tr.Actions.SquashMerge)
+		err := self.c.Git().Branch.Merge(refName, git_commands.MergeOpts{Squash: true})
+		if err = self.CheckMergeOrRebase(err); err != nil {
+			return err
+		}
+		message := utils.ResolvePlaceholderString(self.c.UserConfig.Git.Merging.SquashMergeMessage, map[string]string{
+			"selectedRef":   refName,
+			"currentBranch": checkedOutBranchName,
+		})
+		err = self.c.Git().Commit.CommitCmdObj(message, "").Run()
+		if err != nil {
+			return err
+		}
+		return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+	}
+}
+
 func (self *MergeAndRebaseHelper) ResetMarkedBaseCommit() error {
 	self.c.Modes().MarkedBaseCommit.Reset()
 	return self.c.PostRefreshUpdate(self.c.Contexts().LocalCommits)
