@@ -24,9 +24,7 @@ func (gui *Gui) handleCreateExtrasMenuPanel() error {
 					show := !gui.c.State().GetShowExtrasWindow()
 					gui.c.State().SetShowExtrasWindow(show)
 					gui.c.GetAppState().HideCommandLog = !show
-					if err := gui.c.SaveAppState(); err != nil {
-						gui.c.Log.Errorf("error when saving app state: %v", err)
-					}
+					gui.c.SaveAppStateAndLogError()
 					return nil
 				},
 			},
