@@ -9,7 +9,9 @@ var FilterFuzzy = NewIntegrationTest(NewIntegrationTestArgs{
 	Description:  "Verify that fuzzy filtering works (not just exact matches)",
 	ExtraCmdArgs: []string{},
 	Skip:         false,
-	SetupConfig:  func(config *config.AppConfig) {},
+	SetupConfig: func(config *config.AppConfig) {
+		config.UserConfig.Gui.FilterMode = "fuzzy"
+	},
 	SetupRepo: func(shell *Shell) {
 		shell.NewBranch("this-is-my-branch")
 		shell.EmptyCommit("first commit")
