@@ -12,6 +12,7 @@ var DropTodoCommitWithUpdateRef = NewIntegrationTest(NewIntegrationTestArgs{
 	GitVersion:   AtLeast("2.38.0"),
 	SetupConfig: func(config *config.AppConfig) {
 		config.GetUserConfig().Git.MainBranches = []string{"master"}
+		config.AppState.GitLogShowGraph = "never"
 	},
 	SetupRepo: func(shell *Shell) {
 		shell.
@@ -43,9 +44,9 @@ var DropTodoCommitWithUpdateRef = NewIntegrationTest(NewIntegrationTestArgs{
 				Contains("pick").Contains("CI commit 06"),
 				Contains("pick").Contains("CI commit 05"),
 				Contains("update-ref").Contains("branch1").DoesNotContain("*"),
-				Contains("pick").Contains("CI * commit 04"),
+				Contains("pick").Contains("CI commit 04"),
 				Contains("pick").Contains("CI commit 03"),
-				Contains("<-- YOU ARE HERE --- commit 02"),
+				Contains("<-- YOU ARE HERE --- commit 02").IsSelected(),
 				Contains("CI commit 01"),
 			).
 			NavigateToLine(Contains("commit 06")).
